;;;;;;;;;;;;;;;;;;;;;;;; -*- Mode: Emacs-Lisp -*- ;;;;;;;;;;;;;;;;;;;;;;
;; docbook.el ---
;; Code from various people

;; These automate the entry of entries that often used in the DocBook
;; Documentation.

(add-hook 'sgml-mode-hook
(function (lambda()

    ;; Insert para Element
    
    (defun sgml-para ()
	"Insert para tags and position cursor."
	(interactive)
	(sgml-insert-element 'para))
    (define-key sgml-mode-map "\ep" 'sgml-para)

    ;; Insert literal Element

    (defun sgml-literal ()
	"Insert literal element."
	(interactive)
	(sgml-insert-element 'literal))
    (define-key sgml-mode-map "\C-c\l" 'sgml-literal)

    ;; Insert glossterm Element

    (defun sgml-glossterm ()
	"Insert glossterm element."
        (interactive)
	(sgml-insert-element 'glossterm))
    (define-key sgml-mode-map [(meta control ?T)] 'sgml-glossterm)

    ;; Tag Marked Region as an emphasis Element
    ;; Note that it assumes your cursor is at the end of the region to tag.

    (defun emph-tag ()
	"Tag marked region as an emphasis element (assumes cursor at region end)."
	(interactive)
	(insert "</emphasis>")
	(goto-char (mark))
	(insert "<emphasis>")
	(sgml-next-data-field))
    (define-key sgml-mode-map "\ei" 'emph-tag)

    ;; Inserting Index Tags

    ;; This greatly speeds up index tagging. Just mark the region to add as an
    ;; index tag and press ^Cx. If you want to add a secondary value, press ^Cy
    ;; and enter that value.

    ;; The first one copies the currently marked region and makes it the
    ;; primary value of an index entry. The second assumes that the cursor is
    ;; at the end of the primary element's content (that is, it's on the < in
    ;; the </primary> tag).

    (defun index-tag ()
    "Copy marked section to a primary index tag for it."
	(interactive)
        (kill-ring-save (point)(mark))
	(sgml-insert-element 'indexterm)
	(sgml-insert-element 'primary)
	(yank))
    (define-key sgml-mode-map "\C-c\x" 'index-tag)

    (defun index-tag-sec ()
	"Add secondary index element. Assumes cursor at end of primary element content."
	(interactive)
	(sgml-next-data-field)
	(sgml-insert-element 'secondary))
    (define-key sgml-mode-map "\C-c\y" 'index-tag-sec)

    ;; Coloring Index Elements

    ;; The following sets the content of index-related elements to the
    ;; comment-face color. I'll reset this color to something that blends in or
    ;; stands out from the background depending on whether I'm working on the
    ;; index entries or not.

    (defvar sgml-font-lock-keywords  
	'(; Highlight the text between these tags in SGML mode.
	("<indexterm[^>]*>" . font-lock-comment-face) 
	("</indexterm>" . font-lock-comment-face) 
	("<primary[^<]+</primary>" . font-lock-comment-face) 
	("<secondary[^<]+</secondary>" . font-lock-comment-face) 
	("<see[^<]+</see>" . font-lock-comment-face) 
	("<seealso[^<]+</seealso>" . font-lock-comment-face))
	"Additional expressions to highlight in SGML mode.")

    (setq font-lock-defaults '(sgml-font-lock-keywords t))

    ;; Insert sgmltag Element for an Element Type Name

    (defun sgml-elname ()
	"Insert sgmltag element for an element type name."
	(interactive)
	(insert "<sgmltag class=\"element\"></sgmltag>")
	(backward-char 10))
    (define-key sgml-mode-map "\ee" 'sgml-elname)

    ;; Insert sgmltag Element for an Attribute Type Name

    (defun sgml-atname ()
	"Insert sgmltag element for an attribute name."
	(interactive)
	(insert "<sgmltag class=\"attribute\"></sgmltag>")
	(backward-char 10))
    (define-key sgml-mode-map "\ea" 'sgml-atname)
)))
