;;;;;;;;;;;;;;;;;;;;;;;; -*- Mode: Emacs-Lisp -*- ;;;;;;;;;;;;;;;;;;;;;;
;; misc.el ---
;; Code from various people

;; Miscellaneous

(add-hook 'sgml-mode-hook
(function (lambda()
    ;; Edit Element Attributes by Right-Clicking Mouse
    
    ;; Right-click selected element for edit attributes popup

    (define-key sgml-mode-map [mouse-3] 'sgml-attrib-menu)

    ; Jump Cursor to Beginning or End of Element
    ;; PSGML assigns these commands to the Esc ^A and Esc ^E keystrokes, but 
    ;; ^C home and ^C end easier to remember.

    (global-set-key [?\C-c (home)] 'sgml-beginning-of-element)

    (global-set-key [?\C-c (end)] 'sgml-end-of-element)

    ;; Add a Comment

    (defun sgml-comment ()
    "Insert SGML comment and position cursor."
	(interactive)
	(insert "<!--  -->")
	(backward-char 4))

    (define-key sgml-mode-map "\C-c\o" 'sgml-comment)

    ;; Add an IGNORE Marked Section

    (defun sgml-ignore ()
    "Insert an IGNORE marked section."
    (interactive)
    (insert "<![IGNORE[
    ]]>
    "))
    (define-key sgml-mode-map "\C-c\i" 'sgml-ignore)

    ;; Kill Text from Cursor to End of Element

    (defun sgml-kill-to-eoelement ()  
	"Kill to end of element."
	(interactive)
	(let ((start (point)))
	(sgml-end-of-element)
	(kill-region start (point))))

    (define-key sgml-mode-map "\C-c\k" 'sgml-kill-to-eoelement) 

    ;; Copy Current Element to Buffer

    (defun sgml-copy-element ()
	"Copy the current element to the buffer."
	(interactive)
	(sgml-backward-up-element)
	(let ((start (point)))
	(sgml-forward-element)
	(kill-ring-save start (point))))

    (define-key sgml-mode-map "\C-c\w" 'sgml-copy-element) 

    ;; Fill Element and Save File

    ; sgml-fill-element is PSGML's SGML-intelligent way to rejustify an
    ; element. After making edits to a paragraph, I like to hit one keystroke
    ; (F2) to rejustify the element and save my work.

    (defun sgml-fill-and-save ()
	"Rejustify element at cursor and save file."
	(interactive)
	(sgml-fill-element (sgml-find-element-of (point)))   ; see psgml-edit.el
	(save-buffer))

    (define-key sgml-mode-map [f2] 'sgml-fill-and-save)
)))
